#ifndef MY_STRING_H_
#define MY_STRING_H_

#include"GraphBase.h"

#define dMYSTRING_LENGTH 68

class TMyString{
	private:
		char TmpChar[dMYSTRING_LENGTH];
	public:
		char Text[dMYSTRING_LENGTH];
	public:
		void Clear(void);
	
		void FromInt(int d);
		void FromUInt(unsigned int d);
	
		void FromUInt8Dg(unsigned int data);
		void FromUInt6Dg(unsigned int data);
		void FromUInt4Dg(unsigned int data);
		void FromUInt3Dg(unsigned int data);
		void FromUInt2Dg(unsigned int data);
	
		int GetLength(void);
		int GetEndPst(void);
		void AddOnDgMax6(unsigned int data);
		void AddOn8Dg(unsigned int data);
		void AddOn6Dg(unsigned int data);
		void AddOn4Dg(unsigned int data);
		void AddOn3Dg(unsigned int data);
		void AddOn2Dg(unsigned int data);
	
		void FormFloat(float fd);
		int ToInteger(void);
		float ToFloat(void);
		
		
		void FromStr(const char *source);
		void FromStr(      char *source);
		void FromStr(unsigned char *source);
		void AddOnStr(const char *source);
		void AddOnStr(      char *source);
		void ToStr(char *Dest, unsigned int len);
		int Insert(const char *source, int Pst);
		int Insert(char *source, int Pst);
		unsigned int Delete(int Pst);
		
		void FillFixLen(unsigned int aLen);
		void BrokeFixLen(int aLen);

		static void sClear(char *dest);
		static void sFromStr(char *source, char *dest);
		static void sFromStr(const char *source, char *dest);
		static void sAddOnChar(char aCr, char *dest);
		static void sAddOnStrL32(unsigned char *source, char *dest);
		static void sAddOnStrL32(char *source, char *dest);
		static void sFrom2Dg(unsigned int d, char *dest);
		static void sFrom3Dg(unsigned int d, char *dest);
		static void sFrom4Dg(unsigned int d, char *dest);
		static void sFromUInt(unsigned int data, unsigned char *Text);
		static void sAddOnStr(const char *source, char *dest);
		static void sAddOnStr(unsigned char *source, char *dest);
		static void sAddOnDgMax6(unsigned int data, char *dest);
		static void sAddOn8Dg(unsigned int d, char *dest);
		static void sAddOn7Dg(unsigned int d, char *dest);
		static void sAddOn6Dg(unsigned int d, char *dest);
		static void sAddOn5Dg(unsigned int d, char *dest);
		static void sAddOn4Dg(unsigned int d, char *dest);
		static void sAddOn3Dg(unsigned int d, char *dest);
		static void sAddOn2Dg(unsigned int d, char *dest);
		static void sAddOn1Dg(unsigned int d, char *dest);
		static void sAddOn_N_Dg(int aN, unsigned int d, char *dest);
		static int  sGetLen(char *source);
		static void sFillFixLen(char *source, unsigned int aLen);
		static void sBrokeFixLen(char *source, int aLen);
		static int  sToInteger(char *Src);
		static int  sCompStr32Char(char *pStr1, char *pStr2);
};


#endif









